.. _spider_cbird.at:

cbird.at
--------
Newest releases of the `cbird software <https://cbird.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``cbird.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     cbird.at

